The anorexiaFT data set that comes with the cg package
is in groupcolumns format for the
prepareCGPairedDifferenceData call. Each column
represents a group, and each row represents an individual patient, or
experimental unit. Each observation in a row that spans the two group
columns are paired individual response or outcome values. The 3 groups are regarded as levels of one factor in the
prepareCGPairedDifferenceData, fit, and other methods in
the cg package.
The purpose of the study was to evaluate effects of
multiple treatments on weight as a marker for anorexia, and to
compare their relative effectiveness.
See anorexia in the MASS package for
references and more details.