data(canine)canine data set that comes with the groupcolumns format for the
prepareCGOneFactorData call. Each column represents a group, and
the observations in that group's column are the individual response or
outcome values. The 5 groups are regarded as levels of one factor in the
prepareCGOneFactorData, fit, and other methods in
the
An alternative format of this data set is contained in
canine.listfmt. See that help file for details,
including how it would be read and prepared by
The purpose of this experiment was to evaluate the effect of a physiological dose of estradiol on prostate growth in dogs using ultrasound. See the reference below for details. Comparisons amongst all five groups are of interest.
canine.listfmt, prepareCGOneFactorData