Learn R Programming

cg (version 0.9.0)

canine.listfmt: Canine Data Set in the cg package

Description

A data frame used to illustrate the cg package. It has a One Factor / One-Way / Unpaired Samples layout.

Usage

data(canine.listfmt)

Arguments

Details

The canine.listfmt data set that comes with the cg package is in listed format for the prepareCGOneFactorData call.

The 5 groups are regarded as levels of one factor in the prepareCGOneFactorData, fit, and other methods in the cg package.

canine.listfmt is an alternative format of the canine data set. See that help file for details. Once the data set is prepared into a cgOneFactorData object, all the subsequent methods work on the object in the same way.

The purpose of this experiment was to evaluate the effect of a physiological dose of estradiol on prostate growth in dogs using ultrasound. See the reference below for details. Comparisons amongst all five groups are of interest.

References

Rhodes, L., Ding, V.D.H., Kemp, R.K., Khan, M.S., Nakhla, A.M., Pikounis, B., Rosner, W., Saunders, H.M. and Feeney, W.P. (2000). "Estradiol causes a dose dependent stimulation of prostate growth in castrate beagle dogs." The Prostate, Volume 44, 8-18.

See Also

canine, prepareCGOneFactorData

Examples

Run this code
data(canine.listfmt)
str(canine.listfmt)

## Analogous to prepareCGOneFactorData call on canine data frame format,
##  subsequent methods will work for canine.listfmt.data:

canine.listfmt.data <- prepareCGOneFactorData(canine.listfmt, format="listed",
                                              analysisname="Canine",
                                              endptname="Prostate Volume",
                                              endptunits=expression(plain(cm)^3),
                                              digits=1, logscale=TRUE,
                                              refgrp="CC")
## as they do on canine.data:

canine.data <- prepareCGOneFactorData(canine, format="groupcolumns",
                                      analysisname="Canine",
                                      endptname="Prostate Volume",
                                      endptunits=expression(plain(cm)^3),
                                      digits=1, logscale=TRUE, refgrp="CC")

Run the code above in your browser using DataLab