Learn R Programming

cg (version 1.0-2)

print.cgOneFactorGrpSummaryTable: Print One Factor Group Summary Table object with some format options

Description

Print a cgOneFactorGrpSummaryTable object, which contains a table of group means and variability based on the cgOneFactorFit object.

Usage

## S3 method for class 'cgOneFactorGrpSummaryTable':
print(x, digits = NULL, title = NULL, endptname = NULL, ...)

Arguments

digits
The number of decimal places to use in the output. If NULL, then the number of decimal places is taken from the digits value in the settings slot of the
title
The title printed out with the table. If NULL, it is set to be "Group Summary Table of" the analysisname value from the settings slot of the cg
endptname
The endpoint name, printed out with the table. If NULL, it is set to the endptname value from the settings slot of the cgOneFactorGrpSummary
...
Additional arguments. Only one is currently valid: [object Object] For other possible cgOneFactorGrpSummaryTable table components such as accelerated failure time or unequal variance models, the model ar

Value

  • print.cgOneFactorGrpSummaryTable returns invisible. The main purpose is the side effect of printing to the current output connection, which is typically the console.

Details

The object is printed using a mix of cat and print calls. See cgOneFactorGrpSummaryTable for details of the *.grps and other object slots.

See Also

cgOneFactorGrpSummaryTable

Examples

Run this code
data(canine)
canine.data <- prepareCGOneFactorData(canine, format="groupcolumns",
                                      analysisname="Canine",
                                      endptname="Prostate Volume",
                                      endptunits=expression(plain(cm)^3),
                                      digits=1, logscale=TRUE, refgrp="CC")
canine.fit <- fit(canine.data)

canine.grpsumm <- grpSummaryTable(canine.fit)

print(canine.grpsumm, digits=2)

Run the code above in your browser using DataLab