Learn R Programming

cg (version 1.0-2)

print.cgPairedDifferenceDownweightedTable: Print Downweighted Observations Table object with some format options

Description

Print a cgPairedDifferenceDownweightedTable object, as a table of downweighted observations in a resistant & robust fit from a cgPairedDifferenceFit object.

Usage

## S3 method for class 'cgPairedDifferenceDownweightedTable':
print(x, digits=NULL, title = NULL, endptname = NULL, ...)

Arguments

x
An object of class cgPairedDifferenceDownweightedTable, typically created by downweightedTable.cgPaired
digits
The number of decimal places to use in the output. If NULL, then the number of decimal places is taken from the cgPairedDifferenceDownweightedTable objec
title
The title printed out with the p-value. If NULL, it is set to be "Downweighted Observations Table from Resistant & Robust Fit" of the analysisname value in the settings of the
endptname
The endpoint name, printed out with the p-value. If NULL, it is set to the endptname value in the cgPairedDifferenceDownweightedTable
...
Additional arguments. None are currently defined for this method.

Value

  • print.cgPairedDifferenceDownweightedTable returns invisible. The main purpose is the side effect of printing to the current output connection, which is typically the console. If any observations meet the cutoff criteria, a table is displayed. If no observations meet the cutoff criteria, a text message of table emptiness is displayed instead.

Details

The object is printed using a mix of cat and print calls. See cgPairedDifferenceDownweightedTable for details of the contents and other object slots.

See Also

cgPairedDifferenceDownweightedTable

Examples

Run this code
data(anorexiaFT)

anorexiaFT.data <- prepareCGPairedDifferenceData(anorexiaFT, format="groupcolumns",
                                                 analysisname="Anorexia FT",
                                                 endptname="Weight",
                                                 endptunits="lbs",
                                                 expunitname="Patient",
                                                 digits=1,
                                                 logscale=TRUE)

anorexiaFT.fit <- fit(anorexiaFT.data)

anorexiaFT.dw <- downweightedTable(anorexiaFT.fit, cutoffwt=0.25, display='none') 

print(anorexiaFT.dw)  ## No observation

Run the code above in your browser using DataLab